# This file was first automatically generated by gen-acme-cpanmodules-module-from-acme-cpanlists-list on Sat Sep 22 08:00:33 2018 from module list in Acme::CPANLists::Import::NEILB::Passwords version 0.04.

package Acme::CPANModules::Import::NEILB::Passwords;

our $DATE = '2018-09-22'; # DATE
our $VERSION = '0.001'; # VERSION

our $LIST = {
  description => "This list is generated by extracting module names mentioned in the article [http://neilb.org/reviews/passwords.html]. For the full article, visit the URL.",
  entries     => [
                   { module => "App::Genpass" },
                   { module => "Benchmark" },
                   { module => "Crypt::GeneratePassword" },
                   { module => "Crypt::PW44" },
                   { module => "Crypt::RandPasswd" },
                   { module => "Crypt::XkcdPassword" },
                   { module => "Crypt::YAPassGen" },
                   { module => "Data::Random" },
                   { module => "Data::Random::String" },
                   { module => "Data::SimplePassword" },
                   { module => "Session::Token" },
                   { module => "String::MkPasswd" },
                   { module => "String::Random" },
                   { module => "String::Urandom" },
                   { module => "Text::Password::Pronounceable" },
                 ],
  summary     => "Generating passwords (2012)",
};

1;
# ABSTRACT: Generating passwords (2012)

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModules::Import::NEILB::Passwords - Generating passwords (2012)

=head1 VERSION

This document describes version 0.001 of Acme::CPANModules::Import::NEILB::Passwords (from Perl distribution Acme-CPANModulesBundle-Import-NEILB), released on 2018-09-22.

=head1 DESCRIPTION

Generating passwords (2012).

This list is generated by extracting module names mentioned in the article [http://neilb.org/reviews/passwords.html]. For the full article, visit the URL.

=head1 INCLUDED MODULES

=over

=item * L<App::Genpass>

=item * L<Benchmark>

=item * L<Crypt::GeneratePassword>

=item * L<Crypt::PW44>

=item * L<Crypt::RandPasswd>

=item * L<Crypt::XkcdPassword>

=item * L<Crypt::YAPassGen>

=item * L<Data::Random>

=item * L<Data::Random::String>

=item * L<Data::SimplePassword>

=item * L<Session::Token>

=item * L<String::MkPasswd>

=item * L<String::Random>

=item * L<String::Urandom>

=item * L<Text::Password::Pronounceable>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesBundle-Import-NEILB>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesBundle-Import-NEILB>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModulesBundle-Import-NEILB>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANModules> - about the Acme::CPANModules namespace

L<cpanmodules> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
