# This file was first automatically generated by gen-acme-cpanmodules-module-from-acme-cpanlists-list on Sat Sep 22 08:00:32 2018 from module list in Acme::CPANLists::Import::NEILB::Dependencies version 0.04.

package Acme::CPANModules::Import::NEILB::Dependencies;

our $DATE = '2018-09-22'; # DATE
our $VERSION = '0.001'; # VERSION

our $LIST = {
  description => "This list is generated by extracting module names mentioned in the article [http://neilb.org/reviews/dependencies.html]. For the full article, visit the URL.",
  entries     => [
                   { module => "App::FatPacker::Trace" },
                   { module => "CPAN::Dependency" },
                   { module => "CPAN::FindDependencies" },
                   { module => "Devel::Dependencies" },
                   { module => "Devel::Modlist" },
                   { module => "Devel::TraceDeps" },
                   { module => "Devel::TraceLoad" },
                   { module => "Devel::TraceUse" },
                   { module => "Devel::VersionDump" },
                   { module => "Dist::Requires" },
                   { module => "HTML::Perlinfo::Loaded" },
                   { module => "Module::Dependency::Grapher" },
                   { module => "Module::Depends" },
                   { module => "Module::Extract::Use" },
                   { module => "Module::ExtractUse" },
                   { module => "Module::Info" },
                   { module => "Module::Inspector" },
                   { module => "Module::MakefilePL::Parse" },
                   { module => "Module::Overview" },
                   { module => "Module::ParseDeps" },
                   { module => "Module::ScanDeps" },
                   { module => "Module::Used" },
                   { module => "Perl::PrereqScanner" },
                 ],
  summary     => "Getting module dependency information (2012)",
};

1;
# ABSTRACT: Getting module dependency information (2012)

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModules::Import::NEILB::Dependencies - Getting module dependency information (2012)

=head1 VERSION

This document describes version 0.001 of Acme::CPANModules::Import::NEILB::Dependencies (from Perl distribution Acme-CPANModulesBundle-Import-NEILB), released on 2018-09-22.

=head1 DESCRIPTION

Getting module dependency information (2012).

This list is generated by extracting module names mentioned in the article [http://neilb.org/reviews/dependencies.html]. For the full article, visit the URL.

=head1 INCLUDED MODULES

=over

=item * L<App::FatPacker::Trace>

=item * L<CPAN::Dependency>

=item * L<CPAN::FindDependencies>

=item * L<Devel::Dependencies>

=item * L<Devel::Modlist>

=item * L<Devel::TraceDeps>

=item * L<Devel::TraceLoad>

=item * L<Devel::TraceUse>

=item * L<Devel::VersionDump>

=item * L<Dist::Requires>

=item * L<HTML::Perlinfo::Loaded>

=item * L<Module::Dependency::Grapher>

=item * L<Module::Depends>

=item * L<Module::Extract::Use>

=item * L<Module::ExtractUse>

=item * L<Module::Info>

=item * L<Module::Inspector>

=item * L<Module::MakefilePL::Parse>

=item * L<Module::Overview>

=item * L<Module::ParseDeps>

=item * L<Module::ScanDeps>

=item * L<Module::Used>

=item * L<Perl::PrereqScanner>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesBundle-Import-NEILB>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesBundle-Import-NEILB>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModulesBundle-Import-NEILB>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANModules> - about the Acme::CPANModules namespace

L<cpanmodules> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
