# This file was first automatically generated by gen-acme-cpanmodules-module-from-acme-cpanlists-list on Sat Sep 22 08:00:33 2018 from module list in Acme::CPANLists::Import::NEILB::ModuleLoading version 0.04.

package Acme::CPANModules::Import::NEILB::ModuleLoading;

our $DATE = '2018-09-22'; # DATE
our $VERSION = '0.001'; # VERSION

our $LIST = {
  description => "This list is generated by extracting module names mentioned in the article [http://neilb.org/reviews/module-loading.html]. For the full article, visit the URL.",
  entries     => [
                   { module => "Acme::require::case" },
                   { module => "AnyLoader" },
                   { module => "Class::Autouse" },
                   { module => "Class::LazyLoad" },
                   { module => "Class::Load" },
                   { module => "Class::Load::XS" },
                   { module => "Class::Loader" },
                   { module => "ClassLoader" },
                   { module => "MAD::Loader" },
                   { module => "Module::Hash" },
                   { module => "Module::Implementation" },
                   { module => "Module::Load" },
                   { module => "Module::Load::Conditional" },
                   { module => "Module::Quote" },
                   { module => "Module::Recursive::Require" },
                   { module => "Module::Require" },
                   { module => "Module::Requires" },
                   { module => "Module::Runtime" },
                   { module => "Module::UseFrom" },
                   { module => "Mojo::Loader" },
                   { module => "Mrequire" },
                   { module => "Object::Trampoline" },
                   { module => "UNIVERSAL::require" },
                   { module => "above" },
                   { module => "aliased" },
                   { module => "all" },
                   { module => "autouse" },
                   { module => "base" },
                   { module => "lib::require::all" },
                   { module => "only" },
                   { module => "parent" },
                   { module => "pkg" },
                   { module => "provide" },
                   { module => "relative" },
                   { module => "superclass" },
                   { module => "syntax" },
                   { module => "use" },
                 ],
  summary     => "Modules that (can) load other modules (2013)",
};

1;
# ABSTRACT: Modules that (can) load other modules (2013)

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModules::Import::NEILB::ModuleLoading - Modules that (can) load other modules (2013)

=head1 VERSION

This document describes version 0.001 of Acme::CPANModules::Import::NEILB::ModuleLoading (from Perl distribution Acme-CPANModulesBundle-Import-NEILB), released on 2018-09-22.

=head1 DESCRIPTION

Modules that (can) load other modules (2013).

This list is generated by extracting module names mentioned in the article [http://neilb.org/reviews/module-loading.html]. For the full article, visit the URL.

=head1 INCLUDED MODULES

=over

=item * L<Acme::require::case>

=item * L<AnyLoader>

=item * L<Class::Autouse>

=item * L<Class::LazyLoad>

=item * L<Class::Load>

=item * L<Class::Load::XS>

=item * L<Class::Loader>

=item * L<ClassLoader>

=item * L<MAD::Loader>

=item * L<Module::Hash>

=item * L<Module::Implementation>

=item * L<Module::Load>

=item * L<Module::Load::Conditional>

=item * L<Module::Quote>

=item * L<Module::Recursive::Require>

=item * L<Module::Require>

=item * L<Module::Requires>

=item * L<Module::Runtime>

=item * L<Module::UseFrom>

=item * L<Mojo::Loader>

=item * L<Mrequire>

=item * L<Object::Trampoline>

=item * L<UNIVERSAL::require>

=item * L<above>

=item * L<aliased>

=item * L<all>

=item * L<autouse>

=item * L<base>

=item * L<lib::require::all>

=item * L<only>

=item * L<parent>

=item * L<pkg>

=item * L<provide>

=item * L<relative>

=item * L<superclass>

=item * L<syntax>

=item * L<use>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesBundle-Import-NEILB>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesBundle-Import-NEILB>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModulesBundle-Import-NEILB>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANModules> - about the Acme::CPANModules namespace

L<cpanmodules> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
